"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.After = exports.Before = exports.defineParameterType = exports.Step = exports.defineStep = exports.But = exports.And = exports.Then = exports.When = exports.Given = exports.attach = void 0;
const base64_js_1 = require("base64-js");
const constants_1 = require("./constants");
const registry_1 = require("./registry");
function defineStep(description, implementation) {
    (0, registry_1.getRegistry)().defineStep(description, implementation);
}
exports.Given = defineStep;
exports.When = defineStep;
exports.Then = defineStep;
exports.And = defineStep;
exports.But = defineStep;
exports.defineStep = defineStep;
function runStepDefininition(world, text, argument) {
    (0, registry_1.getRegistry)().runStepDefininition(world, text, argument);
}
exports.Step = runStepDefininition;
function defineParameterType(options) {
    (0, registry_1.getRegistry)().defineParameterType(options);
}
exports.defineParameterType = defineParameterType;
function defineBefore(optionsOrFn, maybeFn) {
    if (typeof optionsOrFn === "function") {
        (0, registry_1.getRegistry)().defineBefore({}, optionsOrFn);
    }
    else if (typeof optionsOrFn === "object" && typeof maybeFn === "function") {
        (0, registry_1.getRegistry)().defineBefore(optionsOrFn, maybeFn);
    }
    else {
        throw new Error("Unexpected argument for Before hook");
    }
}
exports.Before = defineBefore;
function defineAfter(optionsOrFn, maybeFn) {
    if (typeof optionsOrFn === "function") {
        (0, registry_1.getRegistry)().defineAfter({}, optionsOrFn);
    }
    else if (typeof optionsOrFn === "object" && typeof maybeFn === "function") {
        (0, registry_1.getRegistry)().defineAfter(optionsOrFn, maybeFn);
    }
    else {
        throw new Error("Unexpected argument for After hook");
    }
}
exports.After = defineAfter;
function createStringAttachment(data, mediaType, encoding) {
    cy.task(constants_1.TASK_CREATE_STRING_ATTACHMENT, {
        data,
        mediaType,
        encoding,
    });
}
function attach(data, mediaType) {
    if (typeof data === "string") {
        mediaType = mediaType !== null && mediaType !== void 0 ? mediaType : "text/plain";
        if (mediaType.startsWith("base64:")) {
            createStringAttachment(data, mediaType.replace("base64:", ""), "BASE64");
        }
        else {
            createStringAttachment(data, mediaType !== null && mediaType !== void 0 ? mediaType : "text/plain", "IDENTITY");
        }
    }
    else if (data instanceof ArrayBuffer) {
        if (typeof mediaType !== "string") {
            throw Error("ArrayBuffer attachments must specify a media type");
        }
        createStringAttachment((0, base64_js_1.fromByteArray)(new Uint8Array(data)), mediaType, "BASE64");
    }
    else {
        throw Error("Invalid attachment data: must be a ArrayBuffer or string");
    }
}
exports.attach = attach;
